@@ -8,8 +8,14 @@ use Lingua::PT::Abbrev;
 
 require Exporter;
 our @ISA = qw(Exporter);
+
+use POSIX qw(locale_h);
+my $llang = setlocale(LC_CTYPE, "pt_PT");
+$llang    = setlocale(LC_CTYPE, "pt_BR") unless $llang;
 use locale;
 
+use utf8;
+
 
 =encoding UTF-8
 
@@ -31,8 +37,8 @@ Lingua::PT::PLNbase - Perl extension for NLP of the Portuguese
 
 =head1 DESCRIPTION
 
-Este mdulo inclui funes bsicas teis ao processamento
-computacional da lngua, e em particular, da lngua portuguesa.
+Este módulo inclui funções básicas úteis ao processamento
+computacional da língua, e em particular, da língua portuguesa.
 
 =cut
 
@@ -45,20 +51,28 @@ our @EXPORT = qw(
    cqptokens tokenize
 );
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 our $abrev;
 
-our $terminador = qr{([.?!;]+[\"']?|<[pP]\b.*?>|<br>|\n\n+|:\s+(?=[-\"][A-Z]))};
+our $terminador = qr{([.?!;]+[\»"'”’]?|<[pP]\b.*?>|<br>|\n\n+|:\s+(?=[-\«"“‘][A-Z]))};
 
-our $protect = qr'
+our $protect = qr!
        \#n\d+
-    |  \w+\'\w+
+    |  \w+['’]\w+
     |  \bn\.o                                    # number
     |  [\w_.-]+ \@ [\w_.-]+\w                    # emails
-    |  \w+\.?[]\.?                            # ordinals
-    |  <\s*[A-Za-z:]+(?:\s+[A-Za-z:]+=(?:([\'"])[^\'"]+\1)|\w+)*\s*\/?\s*>  # markup open XML SGML
-    |  </\s*[A-Za-z:]+\s*>                       # markup close XML SGML
+    |  \w+\.?[ºª°]\.?                            # ordinals
+    |  _sec[:+].*?_                              # section marks from bookclean
+    |  <[A-Za-z](?:\w|:)*                        # <tag
+         (?:\s+
+            [A-Za-z:0-9]+=                       #   at='v'
+               (?: '[^']+'
+               |   "[^"]+")
+         )*
+         \s*/?\s*
+       >                                         # markup open XML SGML
+    |  </\s*[A-Za-z0-9:]+\s*>                    # markup close XML SGML
     |  \d+(?:\/\d+)+                             # dates or similar 12/21/1
     |  \d+(?:[.,]\d+)+%?                         # numbers
     |  \d+(?:\.[oa])+                            # ordinals numbers  12.o
@@ -66,10 +80,10 @@ our $protect = qr'
     |  (?:\&\w+\;)                               # entidades XML HTML
     |  ((https?|ftp|gopher)://|www)[\w_./~:-]+\w # urls
     |  \w+\.(?:com|org|net|pt)                   # simplified urls
-    |  \w+(-\w+)+                                # d-lo-
+    |  \w+(-\w+)+                                # dá-lo-à
     |  \\\\unicode\{\d+\}                        # unicode...
     |  \w+\.(?:exe|html?|zip|jpg|gif|wav|mp3|png|t?gz|pl|xml) # filenames
-'x;
+!x;
 
 
 our ($savit_n, %savit_p);
@@ -121,38 +135,38 @@ sub _tokenizecommon{
     if ($conf->{keep_quotes}) {
       s#\"# \" #g;
     } else {
-      s/^\"/\ /g;
-      s/ \"/ \ /g;
-      s/\"([ .?!:;,])/ \ $1/g;
-      s/\"$/ \/g;
+      s/^\"/\« /g;
+      s/ \"/ \« /g;
+      s/\"([ .?!:;,])/ \» $1/g;
+      s/\"$/ \»/g;
     }
 
-    s!(\w)('(s|ld|nt|ll|m|t|re))\b!"$1 " . _savit($2)!ge;  # I 'm we 're can 't
+    s!(\w)(['’](s|ld|nt|ll|m|t|re))\b!"$1 " . _savit($2)!ge;  # I 'm we 're can 't
     s!([[:alpha:]]+')(\w)!         _savit($1) . " $2"!ge;
 
     if ($conf->{keep_quotes}) {
       s#\'# \' #g;
     } else {
-      s/^\`/\ /g;
-      s/ \`/ \ /g;
+      s/^\`/\« /g;
+      s/ \`/ \« /g;
 
-      s/^\'/\ /g;
-      s/ \'/ \ /g;
-      s/\'([ .?!:;,])/ \ $1/g;
-      s/\'$/ \/g;
+      s/^\'/\« /g;
+      s/ \'/ \« /g;
+      s/\'([ .?!:;,])/ \» $1/g;
+      s/\'$/ \»/g;
     }
 
     s!($protect)!      _savit($1)!xge;
     s!\b((([A-Z])\.)+)!_savit($1)!gie;
 
-    s!([\\]])!$1 !g; #  | ]
-    s!([\\[])! $1!g;
+    s!([\»\]])!$1 !g; # » | ]
+    s!([\«\[])! $1!g;
 
     s/(\s*\b\s*|\s+)/\n/g;
 
     # s/(.)\n-\n/$1-/g;
     s/\n+/\n/g;
-    s/\n(\.?[])\b/$1/g;
+    s/\n(\.?[ºª°])\b/$1/g;
 
 
     s#\n($abrev)\n\.\n#\n$1\.\n#ig;
@@ -169,15 +183,15 @@ sub _tokenizecommon{
 
 =head2 Atomizadores
 
-Este mdulo inclui um mtodo configurvel para a atomizao de corpus
-na lngua portuguesa. No entanto,  possvel que possa ser usado para
-outras lnguas (especialmente ingls e francs.
+Este módulo inclui um método configurável para a atomização de corpus
+na língua portuguesa. No entanto, é possível que possa ser usado para
+outras línguas (especialmente inglês e francês.
 
-A forma simples de uso do atomizador  usando directamente a funo
-C<atomiza> que retorna um texto em que cada linha contm um tomo (ou
-o uso da funo C<tokeniza> que contm outra verso de atomizador).
+A forma simples de uso do atomizador é usando directamente a função
+C<atomiza> que retorna um texto em que cada linha contém um átomo (ou
+o uso da função C<tokeniza> que contém outra versão de atomizador).
 
-As funes disponveis:
+As funções disponíveis:
 
 =over 4
 
@@ -187,14 +201,14 @@ As funes disponveis:
 
 =item tokenize
 
-Usa um algortmo desenvolvido no Projecto Natura.
+Usa um algorítmo desenvolvido no Projecto Natura.
 
-Para que as aspas no sejam convertidas em I<abrir aspa> e I<fechar
-aspa>, usar a opo de configurao C<keep_quotes>.
+Para que as aspas não sejam convertidas em I<abrir aspa> e I<fechar
+aspa>, usar a opção de configuração C<keep_quotes>.
 
 Retorna texto tokenizado, um por linha (a nao ser que o 'record
 separator' (rs) seja redefenido). Em ambiente lista, retorna a lista
-dos tomos.
+dos átomos.
 
   my @atomos = atomiza($texto);   # tb chamada 'tokenize'
 
@@ -204,18 +218,18 @@ dos tomos.
 
 =item tokeniza
 
-Usa um algoritmo desenvolvido no Plo de Oslo da Linguateca. Retorna
-um tomo por linha em contexto escalar, e uma lista de tomos em
+Usa um algoritmo desenvolvido no Pólo de Oslo da Linguateca. Retorna
+um átomo por linha em contexto escalar, e uma lista de átomos em
 contexto de lista.
 
 =item cqptokens
 
-Um tomo por linha de acordo com notao CWB. Pode ser alterado o
-separador de frases (ou de registo) usando a opo 'irs':
+Um átomo por linha de acordo com notação CWB. Pode ser alterado o
+separador de frases (ou de registo) usando a opção 'irs':
 
    cqptokens( { irs => "\n\n" }, "file" );
 
-outras opes:
+outras opções:
 
    cqptokens( { enc => ":utf8"}, "file" ); # enc => charset
                                            # outenc => charset
@@ -276,10 +290,10 @@ sub cqptokens{        ##
 
 =head2 Segmentadores
 
-Este mdulo  uma extenso Perl para a segmentao de textos em
-linguagem natural. O objectivo principal ser a possibilidade de
-segmentao a vrios nveis, no entanto esta primeira verso permite
-apenas a separao em frases (fraseao) usando uma de duas variantes:
+Este módulo é uma extensão Perl para a segmentação de textos em
+linguagem natural. O objectivo principal será a possibilidade de
+segmentação a vários níveis, no entanto esta primeira versão permite
+apenas a separação em frases (fraseação) usando uma de duas variantes:
 
 =over 4
 
@@ -289,21 +303,21 @@ apenas a separao em frases (fraseao) usando uma de duas variantes:
 
   @frases = frases($texto);
 
-Esta  a implementao do Projecto Natura, que retorna uma lista de
+Esta é a implementação do Projecto Natura, que retorna uma lista de
 frases.
 
 =item C<separa_frases>
 
   $frases = separa_frases($texto);
 
-Esta  a implementao da Linguateca, que retorna um texto com uma
+Esta é a implementação da Linguateca, que retorna um texto com uma
 frase por linha.
 
 =item C<xmlsentences>
 
-Utiliza o mtodo C<frases> e aplica uma etiqueta XML a cada frase. Por omisso,
-as frases so ladeadas por '<s>' e '</s>'. O nome da etiqueta pode ser
-substitudo usando o parametro opcional C<st>.
+Utiliza o método C<frases> e aplica uma etiqueta XML a cada frase. Por omissão,
+as frases são ladeadas por '<s>' e '</s>'. O nome da etiqueta pode ser
+substituído usando o parametro opcional C<st>.
 
   xmlsentences({st=> "tag"}, text)
 
@@ -328,7 +342,7 @@ sub sentences{
   for ($par) {
     s!($protect)!          _savit($1)!xge;
     s!\b(($abrev)\.)!      _savit($1)!ige;
-    s!\b(([A-Z])\.)!       _savit($1)!gie;  # este  parte para no apanhar minlculas (s///i)
+    s!\b(([A-Z])\.)!       _savit($1)!gie;  # este à parte para não apanhar minúlculas (s///i)
     s!($terminador)!$1$MARCA!g;
     $_ = _loadit($_);
     @r = split(/$MARCA/,$_);
@@ -347,62 +361,62 @@ sub _trim {
 }
 
 
-=head2 Segmentao a vrios nveis
+=head2 Segmentação a vários níveis
 
 =over 4
 
 =item fsentences
 
-A funo C<fsentences> permite segmentar um conjunto de ficheiros a
-vrios nveis: por ficheiro, por pargrafo ou por frase. O output pode
-ser realizado em vrios formatos e obtendo, ou no, numerao de
+A função C<fsentences> permite segmentar um conjunto de ficheiros a
+vários níveis: por ficheiro, por parágrafo ou por frase. O output pode
+ser realizado em vários formatos e obtendo, ou não, numeração de
 segmentos.
 
-Esta funo  invocada com uma referncia para um hash de configurao
+Esta função é invocada com uma referência para um hash de configuração
 e uma lista de ficheiros a processar (no caso de a lista ser vazia,
-ir usar o C<STDIN>).
+irá usar o C<STDIN>).
 
-O resultado do processamento  enviado para o C<STDOUT> a no ser que
-a chave C<output> do hash de configurao esteja definida. Nesse caso,
-o seu valor ser usado como ficheiro de resultado.
+O resultado do processamento é enviado para o C<STDOUT> a não ser que
+a chave C<output> do hash de configuração esteja definida. Nesse caso,
+o seu valor será usado como ficheiro de resultado.
 
-A chave C<input_p_sep> permite definir o separador de pargrafos. Por
-omisso,  usada uma linha em branco.
+A chave C<input_p_sep> permite definir o separador de parágrafos. Por
+omissão, é usada uma linha em branco.
 
-A chave C<o_format> define as polticas de etiquetao do
-resultado. De momento, a nica poltica disponvel  a C<XML>.
+A chave C<o_format> define as políticas de etiquetação do
+resultado. De momento, a única política disponível é a C<XML>.
 
 As chaves C<s_tag>, C<p_tag> e C<t_tag> definem as etiquetas a usar,
-na poltica XML, para etiquetar frases, pargrafos e textos
-(ficheiros), respectivamente. Por omisso, as etiquetas usadas so
+na política XML, para etiquetar frases, parágrafos e textos
+(ficheiros), respectivamente. Por omissão, as etiquetas usadas são
 C<s>, C<p> e C<text>.
 
- possvel numerar as etiquetas, definindo as chaves C<s_num>,
+É possível numerar as etiquetas, definindo as chaves C<s_num>,
 C<p_num> ou C<t_num> da seguinte forma:
 
 =over 4
 
 =item '0'
 
-Nenhuma numerao.
+Nenhuma numeração.
 
 =item 'f'
 
-S pode ser usado com o C<t_tag>, e define que as etiquetas que
-delimitam ficheiros usar o nome do ficheiro como identificador.
+Só pode ser usado com o C<t_tag>, e define que as etiquetas que
+delimitam ficheiros usará o nome do ficheiro como identificador.
 
 =item '1'
 
-Numerao a um nvel. Cada etiqueta ter um contador diferente.
+Numeração a um nível. Cada etiqueta terá um contador diferente.
 
 =item '2'
 
-S pode ser usado com o C<p_tag> ou o C<s_tag> e obriga  numerao a
-dois nveis (N.N).
+Só pode ser usado com o C<p_tag> ou o C<s_tag> e obriga à numeração a
+dois níveis (N.N).
 
 =item '3'
 
-S pode ser usado com o C<s_tag> e obriga  numerao a trs nveis (N.N.N)
+Só pode ser usado com o C<s_tag> e obriga à numeração a três níveis (N.N.N)
 
 =back
 
@@ -420,9 +434,9 @@ S pode ser usado com o C<s_tag> e obriga  numerao a trs nveis (N.N.N)
     2 - numercao 2 niveis (N.N)
 
  s: 0 - nenhuma
-    1 - numerao 1 nvel [DEFAULT]
-    2 - numerao 2 nveis (N.N)
-    3 - numerao 3 nveis (N.N.N)
+    1 - numeração 1 nível [DEFAULT]
+    2 - numeração 2 níveis (N.N)
+    3 - numeração 3 níveis (N.N.N)
 
 =cut
 
@@ -619,17 +633,17 @@ sub _close_s_tag {
 
 
 
-=head2 Acentuao
+=head2 Acentuação
 
 =over 4
 
 =item remove_accents
 
-Esta funo remove a acentuao do texto passado como parmetro
+Esta função remove a acentuação do texto passado como parâmetro
 
 =item has_accents
 
-Esta funo verifica se o texto passado como parmetro tem caracteres acentuados
+Esta função verifica se o texto passado como parâmetro tem caracteres acentuados
 
 =back
 
@@ -637,7 +651,7 @@ Esta funo verifica se o texto passado como parmetro tem caracteres acentuados
 
 sub has_accents {
   my $word = shift;
-  if ($word =~ m![]!i) {
+  if ($word =~ m![çáéíóúàèìòùãõâêîôûäëïöüñ]!i) {
     return 1
   } else {
     return 0
@@ -646,8 +660,8 @@ sub has_accents {
 
 sub remove_accents {
   my $word = shift;
-  $word =~ tr//caeiouaeiouaoaeiouaeioun/;
-  $word =~ tr//CAEIOUAEIOUAOAEIOUAEIOUN/;
+  $word =~ tr/çáéíóúàèìòùãõâêîôûäëïöüñ/caeiouaeiouaoaeiouaeioun/;
+  $word =~ tr/ÇÁÉÍÓÚÀÈÌÒÙÃÕÂÊÎÔÛÄËÏÖÜÑ/CAEIOUAEIOUAOAEIOUAEIOUN/;
   return $word;
 }
 
@@ -662,85 +676,85 @@ sub tokeniza {
 
   for ($par) {
     s/([!?]+)/ $1/g;
-    s/([.,;\])/ $1/g;
+    s/([.,;\»´])/ $1/g;
 
-    # separa os dois pontos s se no entre nmeros 9:30...
+    # separa os dois pontos só se não entre números 9:30...
     s/:([^0-9])/ :$1/g;
 
-    # separa os dois pontos s se no entre nmeros e no for http:/...
+    # separa os dois pontos só se não entre números e não for http:/...
     s/([^0-9]):([^\/])/$1 :$2/g;
 
-    # was s/([`])/$1 /g; -- mas tava a dar problemas com o emacs :|
+    # was s/([«`])/$1 /g; -- mas tava a dar problemas com o emacs :|
     s!([`])!$1 !g;
 
-    # s separa o parntesis esquerdo quando no engloba nmeros ou asterisco
+    # só separa o parêntesis esquerdo quando não engloba números ou asterisco
     s/\(([^1-9*])/\( $1/g;
 
-    # s separa o parntesis direito quando no engloba nmeros ou asterisco ou percentagem
+    # só separa o parêntesis direito quando não engloba números ou asterisco ou percentagem
     s/([^0-9*%])\)/$1 \)/g;
 
-    # desfaz a separao dos parnteses para B)
+    # desfaz a separação dos parênteses para B)
     s/> *([A-Za-z]) \)/> $1\)/g;
 
-    # desfaz a separao dos parnteses para (a)
+    # desfaz a separação dos parênteses para (a)
     s/> *\( ([a-z]) \)/> \($1\)/g;
 
-    # separao dos parnteses para ( A4 )
+    # separação dos parênteses para ( A4 )
     s/(\( +[A-Z]+[0-9]+)\)/ $1 \)/g;
 
-    # separa o parntesis recto esquerdo desde que no [..
-    s/\[([^.])/[ $1/g;
+    # separa o parêntesis recto esquerdo desde que não [..
+    s/\[([^.§])/[ $1/g;
 
-    # separa o parntesis recto direito desde que no ..]
-    s/([^.])\]/$1 ]/g;
+    # separa o parêntesis recto direito desde que não ..]
+    s/([^.§])\]/$1 ]/g;
 
-    # separa as reticncias s se no dentro de [...]
-    s/([^[])/$1 /g;
+    # separa as reticências só se não dentro de [...]
+    s/([^[])§/$1 §/g;
 
-    # desfaz a separao dos http:
+    # desfaz a separação dos http:
     s/http :/http:/g;
 
     # separa as aspas anteriores
-    s/ \"/ \ /g;
+    s/ \"/ \« /g;
 
     # separa as aspas anteriores mesmo no inicio
-    s/^\"/ \ /g;
+    s/^\"/ \« /g;
 
     # separa as aspas posteriores
-    s/\" / \ /g;
+    s/\" / \» /g;
 
     # separa as aspas posteriores mesmo no fim
-    s/\"$/ \/g;
+    s/\"$/ \»/g;
 
-    # trata dos apstrofes
-    # trata do apstrofe: s separa se for pelica
+    # trata dos apóstrofes
+    # trata do apóstrofe: só separa se for pelica
     s/([^dDlL])\'([\s\',:.?!])/$1 \'$2/g;
-    # trata do apstrofe: s separa se for pelica
+    # trata do apóstrofe: só separa se for pelica
     s/(\S[dDlL])\'([\s\',:.?!])/$1 \'$2/g;
-    # separa d' do resto da palavra "d'amor"... "dest'poca"
-    s/([A-Za-z])\'([A-Za-z])/$1\' $2/;
+    # separa d' do resto da palavra "d'amor"... "dest'época"
+    s/([A-ZÊÁÉÍÓÚÀÇÔÕÃÂa-zôõçáéíóúâêàã])\'([A-ZÊÁÉÍÓÚÀÇÔÕÃÂa-zôõçáéíóúâêàã])/$1\' $2/;
 
     #Para repor PME's
     s/(\s[A-Z]+)\' s([\s,:.?!])/$1\'s$2/g;
 
-    # isto  para o caso dos apstrofos no terem sido tratados pelo COMPARA
-    # separa um apstrofe final usado como inicial
-    s/ '([A-Za-z])/ ' $1/g;
-    # separa um apstrofe final usado como inicial
-    s/^'([A-Za-z])/' $1/g;
+    # isto é para o caso dos apóstrofos não terem sido tratados pelo COMPARA
+    # separa um apóstrofe final usado como inicial
+    s/ '([A-Za-zÁÓÚÉÊÀÂÍ])/ ' $1/g;
+    # separa um apóstrofe final usado como inicial
+    s/^'([A-Za-zÁÓÚÉÊÀÂÍ])/' $1/g;
 
-    # isto  para o caso dos apstrofes (plicas) serem os do COMPARA
+    # isto é para o caso dos apóstrofes (plicas) serem os do COMPARA
     s/\`([^ ])/\` $1/g;
-    s/([^ ])/$1 /g;
+    s/([^ ])´/$1 ´/g;
 
     # trata dos (1) ou 1)
     # separa casos como Rocha(1) para Rocha (1)
-    s/([a-z])\(([0-9])/$1 \($2/g;
+    s/([a-záéãó])\(([0-9])/$1 \($2/g;
     # separa casos como dupla finalidade:1)
     s/:([0-9]\))/ : $1/g;
 
-    # trata dos hfenes
-    # separa casos como (Itlia)-Juventus para Itlia) -
+    # trata dos hífenes
+    # separa casos como (Itália)-Juventus para Itália) -
     s/\)\-([A-Z])/\) - $1/g;
     # separa casos como 1-universidade
     s/([0-9]\-)([^0-9\s])/$1 $2/g;
@@ -783,33 +797,33 @@ sub tokeniza {
 sub tratar_pontuacao_interna {
   my $par = shift;
 
-  #    print "Estou no pontuao interna... $par\n";
+  #    print "Estou no pontuação interna... $par\n";
 
   for ($par) {
-    # proteger o 
-    s///g;
+    # proteger o §
+    s/§/§§/g;
 
-    # tratar das reticncias
-    s/\.\.\.+//g;
+    # tratar das reticências
+    s/\.\.\.+/§/g;
 
     s/\+/\+\+/g;
 
     # tratar de iniciais seguidas por ponto, eventualmente com
-    # parnteses, no fim de uma frase
+    # parênteses, no fim de uma frase
     s/([A-Z])\. ([A-Z])\.(\s*[])]*\s*)$/$1+ $2+$3 /g;
 
-    # iniciais com espao no meio...
+    # iniciais com espaço no meio...
     s/ a\. C\./ a+C+/g;
     s/ d\. C\./ d+C+/g;
 
     # tratar dos pontos nas abreviaturas
-    s/\./+/g;
-    s/\./+/g;
-    s/\./+/g;
-    s/\./+/g;
+    s/\.º/º+/g;
+    s/º\./+º/g;
+    s/\.ª/+ª/g;
+    s/ª\./ª+/g;
 
-    #s mudar se no for ambguo com ponto final
-    s/\. +([^A-Z\])/+ $1/g;
+    #só mudar se não for ambíguo com ponto final
+    s/º\. +([^A-ZÀÁÉÍÓÚÂÊ\«])/º+ $1/g;
 
     # formas de tratamento
     s/Ex\./Ex+/g; # Ex.
@@ -871,33 +885,33 @@ sub tratar_pontuacao_interna {
     s/ ca\./ ca+/g;
     s/etc\.([.,;])/etc+$1/g;
     s/etc\.\)([.,;])/etc+)$1/g;
-    s/etc\. --( *[a-z,])/etc+ --$1/g;
-    s/etc\.(\)*) ([^A-Z])/etc+$1 $2/g;
+    s/etc\. --( *[a-záéíóúâêà,])/etc+ --$1/g;
+    s/etc\.(\)*) ([^A-ZÀÁÉÍÓÂÊ])/etc+$1 $2/g;
     s/ et\. *al\./ et+al+/g;
     s/ al\./ al+/g; # alameda
     s/ q\.b\./ q+b+/g;
     s/ i\.e\./ i+e+/g;
     s/ibid\./ibid+/g;
-    s/ id\./ id+/g; # se calhar  preciso ver se no vem sempre precedido de um (
+    s/ id\./ id+/g; # se calhar é preciso ver se não vem sempre precedido de um (
     s/op\.( )*cit\./op+$1cit+/g;
     s/P\.S\./P+S+/g;
 
     # unidades de medida
-    s/([0-9][hm])\. ([^A-Z])/$1+ $2/g; # 19h., 24m.
-    s/([0-9][km]m)\. ([^A-Z])/$1+ $2/g; # 20km., 24mm.
-    s/([0-9]kms)\. ([^A-Z])/$1+ $2/g; # kms. !!
+    s/([0-9][hm])\. ([^A-ZÀÁÉÍÓÚÂÊ])/$1+ $2/g; # 19h., 24m.
+    s/([0-9][km]m)\. ([^A-ZÀÁÉÍÓÚÂÊ])/$1+ $2/g; # 20km., 24mm.
+    s/([0-9]kms)\. ([^A-ZÀÁÉÍÓÚÂÊ])/$1+ $2/g; # kms. !!
     s/(\bm)\./$1+/g; # metros no MINHO
 
     # outros
     s/\(([Oo]rgs*)\.\)/($1+)/g; # (orgs.)
     s/\(([Ee]ds*)\.\)/($1+)/g; # (eds.)
-    s/sc\./sc+/g;
-    s/pg(s*)\./pg$1+/g;
+    s/séc\./séc+/g;
+    s/pág(s*)\./pág$1+/g;
     s/pg\./pg+/g;
     s/pag\./pag+/g;
     s/ ed\./ ed+/g;
     s/Ed\./Ed+/g;
-    s/ sb\./ sb+/g;
+    s/ sáb\./ sáb+/g;
     s/ dom\./ dom+/g;
     s/ id\./ id+/g;
     s/ min\./ min+/g;
@@ -952,7 +966,7 @@ sub tratar_pontuacao_interna {
     # Abreviaturas francesas
     s/Mme\./Mme+/g;
 
-    # Abreviaturas especiais do Dirio do Minho
+    # Abreviaturas especiais do Diário do Minho
     s/ habilit\./ habilit+/g;
     s/Hab\./Hab+/g;
     s/Mot\./Mot+/g;
@@ -982,21 +996,21 @@ sub tratar_pontuacao_interna {
     #	print "SIGLA: $sigla\n";
   }
 
-  # tratar de pares de iniciais ligadas por hfen ( francesa: A.-F.)
+  # tratar de pares de iniciais ligadas por hífen (à francesa: A.-F.)
   for ($par) {
     s/ ([A-Z])\.\-([A-Z])\. / $1+-$2+ /g;
-    # tratar de iniciais (nicas?) seguidas por ponto
+    # tratar de iniciais (únicas?) seguidas por ponto
     s/ ([A-Z])\. / $1+ /g;
     # tratar de iniciais seguidas por ponto
     s/^([A-Z])\. /$1+ /g;
-    # tratar de iniciais seguidas por ponto antes de aspas "D. Joo
+    # tratar de iniciais seguidas por ponto antes de aspas "D. João
     # VI: Um Rei Aclamado"
-    s/([("\])([A-Z])\. /$1$2+ /g;
+    s/([("\«])([A-Z])\. /$1$2+ /g;
   }
 
-  # Tratar dos URLs (e tambm dos endereos de email)
+  # Tratar dos URLs (e também dos endereços de email)
   # email= url@url...
-  # aceito endereos seguidos de /hgdha/hdga.html
+  # aceito endereços seguidos de /hgdha/hdga.html
   #  seguidos de /~hgdha/hdga.html
   #    @urls=($par=~/(?:[a-z][a-z0-9-]*\.)+(?:[a-z]+)(?:\/~*[a-z0-9-]+)*?(?:\/~*[a-z0-9][a-z0-9.-]+)*(?:\/[a-z.]+\?[a-z]+=[a-z0-9-]+(?:\&[a-z]+=[a-z0-9-]+)*)*/gi);
 
@@ -1004,21 +1018,21 @@ sub tratar_pontuacao_interna {
   my $url_antigo;
   foreach my $url (@urls) {
     $url_antigo = $url;
-    $url_antigo =~ s/\./\\./g; # para impedir a substituio de P.o em vez de P\.o
+    $url_antigo =~ s/\./\\./g; # para impedir a substituição de P.o em vez de P\.o
     $url_antigo =~ s/\?/\\?/g;
     $url =~ s/\./+/g;
-    # Se o ltimo ponto est mesmo no fim, no faz parte do URL
+    # Se o último ponto está mesmo no fim, não faz parte do URL
     $url =~ s/\+$/./;
-    $url =~ s/\//\/\/\/\//g; # pe quatro ////
+    $url =~ s/\//\/\/\/\//g; # põe quatro ////
     $par =~ s/$url_antigo/$url/;
   }
   # print "Depois de tratar dos URLs: $par\n";
 
   for ($par) {
-    # de qualquer maneira, se for um ponto seguido de uma vrgula, 
+    # de qualquer maneira, se for um ponto seguido de uma vírgula, é
     # abreviatura...
     s/\. *,/+,/g;
-    # de qualquer maneira, se for um ponto seguido de outro ponto, 
+    # de qualquer maneira, se for um ponto seguido de outro ponto, é
     # abreviatura...
     s/\. *\./+./g;
 
@@ -1027,10 +1041,10 @@ sub tratar_pontuacao_interna {
     s/([0-9]+)\.([0-9]+)/$1_$2/g;
 
     # tratamento de numerais cardinais
-    # - tratar dos nmeros com ponto no incio da frase
+    # - tratar dos números com ponto no início da frase
     s/^([0-9]+)\. /$1+ /g;
-    # - tratar dos nmeros com ponto antes de minsculas
-    s/([0-9]+)\. ([a-z])/$1+ $2/g;
+    # - tratar dos números com ponto antes de minúsculas
+    s/([0-9]+)\. ([a-záéíóúâêà])/$1+ $2/g;
 
     # tratamento de numerais ordinais acabados em .o
     s/([0-9]+)\.([oa]s*) /$1+$2 /g;
@@ -1042,8 +1056,8 @@ sub tratar_pontuacao_interna {
 
     #print "TRATA: $par\n";
 
-    # tratar indicao de horas
-    #   esta  tratada na tokenizao - no separando 9:20 em 9 :20
+    # tratar indicação de horas
+    #   esta é tratada na tokenização - não separando 9:20 em 9 :20
   }
   return $par;
 }
@@ -1060,105 +1074,105 @@ sub separa_frases {
 
   for ($par) {
 
-    # primeiro junto os ) e os -- ao caracter anterior de pontuao
-    s/([?!.])\s+\)/$1\)/g; # pr  "ola? )" para "ola?)"
-    s/([?!.])\s+\-/$1-/g; # pr  "ola? --" para "ola?--"
-    s/([?!.])\s+/$1/g; # pr  "ola? ..." para "ola?..."
-    s/\s+\-/$1-/g; # pr  "ola --" para "ola--"
+    # primeiro junto os ) e os -- ao caracter anterior de pontuação
+    s/([?!.])\s+\)/$1\)/g; # pôr  "ola? )" para "ola?)"
+    s/([?!.])\s+\-/$1-/g; # pôr  "ola? --" para "ola?--"
+    s/([?!.])\s+§/$1§/g; # pôr  "ola? ..." para "ola?..."
+    s/§\s+\-/$1-/g; # pôr  "ola§ --" para "ola§--"
 
-    # junto tb o travesso -- `a pelica '
+    # junto tb o travessão -- `a pelica '
     s/\-\- \' *$/\-\-\' /;
 
-    # separar esta pontuao, apenas se no for dentro de aspas, ou
-    # seguida por vrgulas ou parnteses o a-z esto l para no
+    # separar esta pontuação, apenas se não for dentro de aspas, ou
+    # seguida por vírgulas ou parênteses o a-z estáo lá para não
     # separar /asp?id=por ...
-    s/([?!]+)([^-\',?!)"a-z])/$1.$2/g;
+    s/([?!]+)([^-\»'´,§?!)"a-z])/$1.$2/g;
 
-    # Deixa-se o travesso para depois
+    # Deixa-se o travessão para depois
     # print "Depois de tratar do ?!: $par";
 
-    # separar as reticncias entre parnteses apenas se forem seguidas
-    # de nova frase, e se no comearem uma frase elas prprias
-    s/([\w?!])([\"']*\)) *([A-Z])/$1$2.$3/g;
+    # separar as reticências entre parênteses apenas se forem seguidas
+    # de nova frase, e se não começarem uma frase elas próprias
+    s/([\w?!])§([\»"´']*\)) *([A-ZÁÉÍÓÚÀ])/$1§$2.$3/g;
 
     # print "Depois de tratar das retic. seguidas de ): $par";
 
-    # separar os pontos antes de parnteses se forem seguidos de nova
+    # separar os pontos antes de parênteses se forem seguidos de nova
     # frase
-    s/([\w])\.([)]) *([A-Z])/$1 + $2.$3/g;
+    s/([\w])\.([)]) *([A-ZÁÉÍÓÚÀ])/$1 + $2.$3/g;
 
-    # separar os pontos ? e ! antes de parnteses se forem seguidos de
-    # nova frase, possivelmente tb iniciada por abre parnteses ou
-    # travesso
-    s/(\w[?!]+)([)]) *((?:\( |\-\- )*[A-Z])/$1 $2.$3/g;
+    # separar os pontos ? e ! antes de parênteses se forem seguidos de
+    # nova frase, possivelmente tb iniciada por abre parênteses ou
+    # travessão
+    s/(\w[?!]+)([)]) *((?:\( |\-\- )*[A-ZÁÉÍÓÚÀ])/$1 $2.$3/g;
 
-    # separar as reticncias apenas se forem seguidas de nova frase, e
-    # se no comearem uma frase elas prprias trata tambm das
-    # reticncias antes de aspas
-    s/([\w\d!?])\s*(["\']*) ([^\"'a-z,;?!)])/$1$2.$3/g;
-    s/([\w\d!?])\s*(["\']*)\s*$/$1$2. /g;
+    # separar as reticências apenas se forem seguidas de nova frase, e
+    # se não começarem uma frase elas próprias trata também das
+    # reticências antes de aspas
+    s/([\w\d!?])\s*§(["\»'´]*) ([^\»"'a-záéíóúâêàäëïöü,;?!)])/$1§$2.$3/g;
+    s/([\w\d!?])\s*§(["\»'´]*)\s*$/$1§$2. /g;
 
     # aqui trata das frases acabadas por aspas, eventualmente tb
-    # fechando parnteses e seguidas por reticncias
-    s/([\w!?]["\'])(\)*) ([^\"a-z,;?!)])/$1$2.$3/g;
+    # fechando parênteses e seguidas por reticências
+    s/([\w!?]["\»'´])§(\)*) ([^\»"a-záéíóúâêàäëïöü,;?!)])/$1§$2.$3/g;
 
     #print "depois de tratar das reticencias seguidas de nova frase: $par\n";
 
     # tratar dos dois pontos: apenas se seguido por discurso directo
-    # em maisculas
-    s/: \([A-Z])/:.\$1/g;
-    s/: (\-\-[ \]*[A-Z])/:.$1/g;
+    # em maiúsculas
+    s/: \«([A-ZÁÉÍÓÚÀ])/:.\«$1/g;
+    s/: (\-\-[ \«]*[A-ZÁÉÍÓÚÀ])/:.$1/g;
 
-    # tratar dos dois pontos se eles acabam o pargrafo ( preciso pr
-    # um espao)
+    # tratar dos dois pontos se eles acabam o parágrafo (é preciso pôr
+    # um espaço)
     s/:\s*$/:. /;
 
     # tratar dos pontos antes de aspas
-    s/\.(["\'])([^.])/+$1.$2/g;
+    s/\.(["\»'´])([^.])/+$1.$2/g;
 
     # tratar das aspas quando seguidas de novas aspas
-    s/\\s*[\"]/\. \/g;
+    s/\»\s*[\«"]/\». \«/g;
 
-    # tratar de ? e ! seguidos de aspas quando seguidos de maiscula
-    # eventualmente iniciados por abre parnteses ou por travesso
-    s/([?!])([\"']) ((?:\( |\-\- )*[A-Z])/$1$2. $3/g;
+    # tratar de ? e ! seguidos de aspas quando seguidos de maiúscula
+    # eventualmente iniciados por abre parênteses ou por travessão
+    s/([?!])([\»"'´]) ((?:\( |\-\- )*[A-ZÁÉÍÓÚÀÊÂ])/$1$2. $3/g;
 
-    # separar os pontos ? e ! antes de parnteses e possivelmente
-    # aspas se forem o fim do pargrafo
-    s/(\w[?!]+)([)][\"']*) *$/$1 $2./;
+    # separar os pontos ? e ! antes de parênteses e possivelmente
+    # aspas se forem o fim do parágrafo
+    s/(\w[?!]+)([)][\»"'´]*) *$/$1 $2./;
 
     # tratar dos pontos antes de aspas precisamente no fim
-    s/\.([\"'])\s*$/+$1. /g;
+    s/\.([\»"'´])\s*$/+$1. /g;
 
-    # tratar das reticncias e outra pontuao antes de aspas ou
+    # tratar das reticências e outra pontuação antes de aspas ou
     # plicas precisamente no fim
-    s/([!?])([\"']+)\s*$/$1$2. /g;
+    s/([!?§])([\»"'´]+)\s*$/$1$2. /g;
 
-    #tratar das reticncias precisamente no fim
-    s/\s*$/. /g;
+    #tratar das reticências precisamente no fim
+    s/§\s*$/§. /g;
 
-    # tratar dos pontos antes de parntesis precisamente no fim
+    # tratar dos pontos antes de parêntesis precisamente no fim
     s/\.\)\s*$/+\). /g;
 
     # aqui troco .) por .). ...
     s/\.\)\s/+\). /g;
   }
 
-  # tratar de pargrafos que acabam em letras, nmeros, vrgula ou
+  # tratar de parágrafos que acabam em letras, números, vírgula ou
   # "-", chamando-os fragmentos #ALTERACAO
   my $fragmento;
-  if ($par =~/[A-Za-z0-9\),-][\\"\'>]*\s*\)*\s*$/) {
+  if ($par =~/[A-Za-záéíóúêãÁÉÍÓÚÀ0-9\),-][\»\"\'´>]*\s*\)*\s*$/) {
     $fragmento = 1
   }
 
   for ($par) {
-    # se o pargrafo acaba em "+", deve-se juntar "." outra vez.
+    # se o parágrafo acaba em "+", deve-se juntar "." outra vez.
     s/([^+])\+\s*$/$1+. /;
 
-    # se o pargrafo acaba em abreviatura (+) seguido de aspas ou parntesis, deve-se juntar "."
-    s/([^+])\+\s*(["\'\)])\s*$/$1+$2. /;
+    # se o parágrafo acaba em abreviatura (+) seguido de aspas ou parêntesis, deve-se juntar "."
+    s/([^+])\+\s*(["\»'´\)])\s*$/$1+$2. /;
 
-    # print "Pargrafo antes da separao: $par";
+    # print "Parágrafo antes da separação: $par";
   }
 
   my @sentences = split /\./,$par;
@@ -1167,14 +1181,14 @@ sub separa_frases {
   }
 
   my $resultado = "";
-  # para saber em que frase pr <s frag>
+  # para saber em que frase pôr <s frag>
   my $num_frase_no_paragrafo = 0;
   foreach my $frase (@sentences) {
     $frase = &recupera_ortografia_certa($frase);
 
-    if (($frase=~/[.?!:;][\"']*\s*$/) or
-	($frase=~/[.?!] *\)[\"']*$/)) {
-      # frase normal acabada por pontuao
+    if (($frase=~/[.?!:;][\»"'´]*\s*$/) or
+	($frase=~/[.?!] *\)[\»"'´]*$/)) {
+      # frase normal acabada por pontuação
       $resultado .= "<s> $frase </s>\n";
     }
 
@@ -1193,19 +1207,19 @@ sub separa_frases {
 
 
 sub recupera_ortografia_certa {
-  # os sinais literais de + so codificados como "++" para evitar
-  # transformao no ponto, que  o significado do "+"
+  # os sinais literais de + são codificados como "++" para evitar
+  # transformação no ponto, que é o significado do "+"
 
   my $par = shift;
 
   for ($par) {
-    s/([^+])\+(?!\+)/$1./g; # um + no seguido por +
+    s/([^+])\+(?!\+)/$1./g; # um + não seguido por +
     s/\+\+/+/g;
-    s/^(?!)/.../g; # se as reticncias comeam a frase
-    s/([^(])(?!)\)/$1... \)/g; # porque se juntou no separa_frases 
+    s/^§(?!§)/.../g; # se as reticências começam a frase
+    s/([^§(])§(?!§)\)/$1... \)/g; # porque se juntou no separa_frases 
     # So nao se faz se for (...) ...
-    s/([^])(?!)/$1.../g; # um  no seguido por 
-    s///g;
+    s/([^§])§(?!§)/$1.../g; # um § não seguido por §
+    s/§§/§/g;
     s/_/./g;
     s/#/,/g;
     s#////#/#g; #passa 4 para 1
@@ -1220,7 +1234,7 @@ sub recupera_ortografia_certa {
 __END__
 
 
-=head2 Funes auxiliares
+=head2 Funções auxiliares
 
 =over 4
 
@@ -1240,7 +1254,7 @@ Alberto Simoes (ambs@di.uminho.pt)
 
 Diana Santos (diana.santos@sintef.no)
 
-Jos Joo Almeida (jj@di.uminho.pt)
+José João Almeida (jj@di.uminho.pt)
 
 Paulo Rocha (paulo.rocha@di.uminho.pt)
 
@@ -1254,10 +1268,10 @@ it under the same terms as Perl itself, either Perl version 5.8.1 or,
 at your option, any later version of Perl 5 you may have available.
 
 (PT)
-Esta biblioteca  software de domnio pblico; pode redistribuir e/ou
-modificar este mdulo nos mesmos termos do prprio Perl, quer seja a
-verso 5.8.1 ou, na sua liberdade, qualquer outra verso do Perl 5 que
-tenha disponvel.
+Esta biblioteca é software de domínio público; pode redistribuir e/ou
+modificar este módulo nos mesmos termos do próprio Perl, quer seja a
+versão 5.8.1 ou, na sua liberdade, qualquer outra versão do Perl 5 que
+tenha disponível.
 
 =cut
 
